"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EvmContracts = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const ethers_contracts = __importStar(require("./ethers-contracts"));
/**
 * @category EVM
 * Evm Contracts class. Contains methods for accessing ts interfaces for all available contracts
 */
class EvmContracts {
    _contracts;
    constructor(conf) {
        this._contracts = new Map();
        Object.entries(conf).forEach(([c, cfg]) => {
            this._contracts.set(c, cfg.contracts);
        });
    }
    /**
     * Returns contract addresses for the chain
     *
     * @returns The contract addresses
     */
    getContracts(chain) {
        const chainName = (0, connect_sdk_1.toChainName)(chain);
        const contracts = this._contracts.get(chainName);
        if (!contracts)
            throw new Error(`no EVM contracts found for ${chain}`);
        return contracts;
    }
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, errors if not found
     */
    getCore(chain, connection) {
        const address = this.getContracts(chain).coreBridge;
        if (!address)
            throw new Error(`Core contract for domain ${chain} not found`);
        return ethers_contracts.Wormhole__factory.connect(address, connection);
    }
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, errors if not found
     */
    getTokenBridge(chain, connection) {
        const address = this.getContracts(chain).tokenBridge;
        if (!address)
            throw new Error(`Bridge contract for domain ${chain} not found`);
        return ethers_contracts.Bridge__factory.connect(address, connection);
    }
    static getTokenImplementation(connection, address) {
        const ti = ethers_contracts.TokenImplementation__factory.connect(address, connection);
        if (!ti)
            throw new Error(`No token implementation available for: ${address}`);
        return ti;
    }
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, undefined if not found
     */
    getNftBridge(chain, connection) {
        const address = this.getContracts(chain).nftBridge;
        if (!address)
            return undefined;
        return ethers_contracts.NFTBridge__factory.connect(address, connection);
    }
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, errors if not found
     */
    mustGetNftBridge(chain, connection) {
        const nftBridge = this.getNftBridge(chain, connection);
        if (!nftBridge)
            throw new Error(`NFT Bridge contract for domain ${chain} not found`);
        return nftBridge;
    }
    /**
     * Returns wormhole Token Bridge Relayer contract for the chain
     *
     * @returns An interface for the Token Bridge Relayer contract, errors if not found
     */
    getTokenBridgeRelayer(chain, connection) {
        const address = this.getContracts(chain).relayer;
        if (!address)
            throw new Error(`Token Bridge Relayer contract for domain ${chain} not found`);
        return ethers_contracts.TokenBridgeRelayer__factory.connect(address, connection);
    }
    /**
     * Returns wormhole CCTP relayer contract for the chain
     *
     * @returns An interface for the Wormhole CCTP relayer contract, errors if not found
     */
    getWormholeCircleRelayer(chain, connection) {
        const relayerAddress = this.getContracts(chain).cctp?.wormholeRelayer;
        if (!relayerAddress)
            throw new Error(`Wormhole Circle relayer contract for domain ${chain} not found`);
        return ethers_contracts.CircleRelayer__factory.connect(relayerAddress, connection);
    }
    getCircleTokenMessenger(chain, connection) {
        const address = this.getContracts(chain).cctp.tokenMessenger;
        if (!address)
            throw new Error(`Circle Token Messenger contract for domain ${chain} not found`);
        return ethers_contracts.TokenMessenger__factory.connect(address, connection);
    }
    getCircleMessageTransmitter(chain, connection) {
        const address = this.getContracts(chain).cctp?.messageTransmitter;
        if (!address)
            throw new Error(`Circle Messenge Transmitter contract for domain ${chain} not found`);
        return ethers_contracts.MessageTransmitter__factory.connect(address, connection);
    }
    getCoreImplementationInterface() {
        return ethers_contracts.Implementation__factory.createInterface();
    }
    getCoreImplementation(chain, connection) {
        const address = this.getContracts(chain).coreBridge;
        if (!address)
            throw new Error('Core bridge address not found');
        return ethers_contracts.Implementation__factory.connect(address, connection);
    }
    async getNativeWrapped(chain, connection) {
        const address = (0, connect_sdk_1.toNative)(chain, await this.getTokenBridge(chain, connection).WETH());
        return { address, chain };
    }
}
exports.EvmContracts = EvmContracts;
//# sourceMappingURL=contracts.js.map