import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from 'ethers';
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from './common';
export declare namespace NFTBridgeStructs {
    type TransferStruct = {
        tokenAddress: BytesLike;
        tokenChain: BigNumberish;
        symbol: BytesLike;
        name: BytesLike;
        tokenID: BigNumberish;
        uri: string;
        to: BytesLike;
        toChain: BigNumberish;
    };
    type TransferStructOutput = [
        tokenAddress: string,
        tokenChain: bigint,
        symbol: string,
        name: string,
        tokenID: bigint,
        uri: string,
        to: string,
        toChain: bigint
    ] & {
        tokenAddress: string;
        tokenChain: bigint;
        symbol: string;
        name: string;
        tokenID: bigint;
        uri: string;
        to: string;
        toChain: bigint;
    };
    type RecoverChainIdStruct = {
        module: BytesLike;
        action: BigNumberish;
        evmChainId: BigNumberish;
        newChainId: BigNumberish;
    };
    type RecoverChainIdStructOutput = [
        module: string,
        action: bigint,
        evmChainId: bigint,
        newChainId: bigint
    ] & {
        module: string;
        action: bigint;
        evmChainId: bigint;
        newChainId: bigint;
    };
    type RegisterChainStruct = {
        module: BytesLike;
        action: BigNumberish;
        chainId: BigNumberish;
        emitterChainID: BigNumberish;
        emitterAddress: BytesLike;
    };
    type RegisterChainStructOutput = [
        module: string,
        action: bigint,
        chainId: bigint,
        emitterChainID: bigint,
        emitterAddress: string
    ] & {
        module: string;
        action: bigint;
        chainId: bigint;
        emitterChainID: bigint;
        emitterAddress: string;
    };
    type UpgradeContractStruct = {
        module: BytesLike;
        action: BigNumberish;
        chainId: BigNumberish;
        newContract: BytesLike;
    };
    type UpgradeContractStructOutput = [
        module: string,
        action: bigint,
        chainId: bigint,
        newContract: string
    ] & {
        module: string;
        action: bigint;
        chainId: bigint;
        newContract: string;
    };
}
export declare namespace NFTBridgeStorage {
    type SPLCacheStruct = {
        name: BytesLike;
        symbol: BytesLike;
    };
    type SPLCacheStructOutput = [name: string, symbol: string] & {
        name: string;
        symbol: string;
    };
}
export interface NFTBridgeInterface extends Interface {
    getFunction(nameOrSignature: 'bridgeContracts' | 'chainId' | 'completeTransfer' | 'encodeTransfer' | 'evmChainId' | 'finality' | 'governanceActionIsConsumed' | 'governanceChainId' | 'governanceContract' | 'isFork' | 'isInitialized' | 'isTransferCompleted' | 'isWrappedAsset' | 'onERC721Received' | 'parseRecoverChainId' | 'parseRegisterChain' | 'parseTransfer' | 'parseUpgrade' | 'registerChain' | 'splCache' | 'submitRecoverChainId' | 'tokenImplementation' | 'transferNFT' | 'upgrade' | 'wormhole' | 'wrappedAsset'): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: 'AdminChanged' | 'BeaconUpgraded' | 'ContractUpgraded' | 'Upgraded'): EventFragment;
    encodeFunctionData(functionFragment: 'bridgeContracts', values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: 'chainId', values?: undefined): string;
    encodeFunctionData(functionFragment: 'completeTransfer', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'encodeTransfer', values: [NFTBridgeStructs.TransferStruct]): string;
    encodeFunctionData(functionFragment: 'evmChainId', values?: undefined): string;
    encodeFunctionData(functionFragment: 'finality', values?: undefined): string;
    encodeFunctionData(functionFragment: 'governanceActionIsConsumed', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'governanceChainId', values?: undefined): string;
    encodeFunctionData(functionFragment: 'governanceContract', values?: undefined): string;
    encodeFunctionData(functionFragment: 'isFork', values?: undefined): string;
    encodeFunctionData(functionFragment: 'isInitialized', values: [AddressLike]): string;
    encodeFunctionData(functionFragment: 'isTransferCompleted', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'isWrappedAsset', values: [AddressLike]): string;
    encodeFunctionData(functionFragment: 'onERC721Received', values: [AddressLike, AddressLike, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: 'parseRecoverChainId', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'parseRegisterChain', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'parseTransfer', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'parseUpgrade', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'registerChain', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'splCache', values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: 'submitRecoverChainId', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'tokenImplementation', values?: undefined): string;
    encodeFunctionData(functionFragment: 'transferNFT', values: [AddressLike, BigNumberish, BigNumberish, BytesLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: 'upgrade', values: [BytesLike]): string;
    encodeFunctionData(functionFragment: 'wormhole', values?: undefined): string;
    encodeFunctionData(functionFragment: 'wrappedAsset', values: [BigNumberish, BytesLike]): string;
    decodeFunctionResult(functionFragment: 'bridgeContracts', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'chainId', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'completeTransfer', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'encodeTransfer', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'evmChainId', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'finality', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'governanceActionIsConsumed', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'governanceChainId', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'governanceContract', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'isFork', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'isInitialized', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'isTransferCompleted', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'isWrappedAsset', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'onERC721Received', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'parseRecoverChainId', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'parseRegisterChain', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'parseTransfer', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'parseUpgrade', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'registerChain', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'splCache', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'submitRecoverChainId', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'tokenImplementation', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'transferNFT', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'upgrade', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'wormhole', data: BytesLike): Result;
    decodeFunctionResult(functionFragment: 'wrappedAsset', data: BytesLike): Result;
}
export declare namespace AdminChangedEvent {
    type InputTuple = [previousAdmin: AddressLike, newAdmin: AddressLike];
    type OutputTuple = [previousAdmin: string, newAdmin: string];
    interface OutputObject {
        previousAdmin: string;
        newAdmin: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace BeaconUpgradedEvent {
    type InputTuple = [beacon: AddressLike];
    type OutputTuple = [beacon: string];
    interface OutputObject {
        beacon: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace ContractUpgradedEvent {
    type InputTuple = [oldContract: AddressLike, newContract: AddressLike];
    type OutputTuple = [oldContract: string, newContract: string];
    interface OutputObject {
        oldContract: string;
        newContract: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace UpgradedEvent {
    type InputTuple = [implementation: AddressLike];
    type OutputTuple = [implementation: string];
    interface OutputObject {
        implementation: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface NFTBridge extends BaseContract {
    connect(runner?: ContractRunner | null): NFTBridge;
    waitForDeployment(): Promise<this>;
    interface: NFTBridgeInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    bridgeContracts: TypedContractMethod<[
        chainId_: BigNumberish
    ], [
        string
    ], 'view'>;
    chainId: TypedContractMethod<[], [bigint], 'view'>;
    completeTransfer: TypedContractMethod<[
        encodedVm: BytesLike
    ], [
        void
    ], 'nonpayable'>;
    encodeTransfer: TypedContractMethod<[
        transfer: NFTBridgeStructs.TransferStruct
    ], [
        string
    ], 'view'>;
    evmChainId: TypedContractMethod<[], [bigint], 'view'>;
    finality: TypedContractMethod<[], [bigint], 'view'>;
    governanceActionIsConsumed: TypedContractMethod<[
        hash: BytesLike
    ], [
        boolean
    ], 'view'>;
    governanceChainId: TypedContractMethod<[], [bigint], 'view'>;
    governanceContract: TypedContractMethod<[], [string], 'view'>;
    isFork: TypedContractMethod<[], [boolean], 'view'>;
    isInitialized: TypedContractMethod<[impl: AddressLike], [boolean], 'view'>;
    isTransferCompleted: TypedContractMethod<[
        hash: BytesLike
    ], [
        boolean
    ], 'view'>;
    isWrappedAsset: TypedContractMethod<[token: AddressLike], [boolean], 'view'>;
    onERC721Received: TypedContractMethod<[
        operator: AddressLike,
        arg1: AddressLike,
        arg2: BigNumberish,
        arg3: BytesLike
    ], [
        string
    ], 'view'>;
    parseRecoverChainId: TypedContractMethod<[
        encodedRecoverChainId: BytesLike
    ], [
        NFTBridgeStructs.RecoverChainIdStructOutput
    ], 'view'>;
    parseRegisterChain: TypedContractMethod<[
        encoded: BytesLike
    ], [
        NFTBridgeStructs.RegisterChainStructOutput
    ], 'view'>;
    parseTransfer: TypedContractMethod<[
        encoded: BytesLike
    ], [
        NFTBridgeStructs.TransferStructOutput
    ], 'view'>;
    parseUpgrade: TypedContractMethod<[
        encoded: BytesLike
    ], [
        NFTBridgeStructs.UpgradeContractStructOutput
    ], 'view'>;
    registerChain: TypedContractMethod<[
        encodedVM: BytesLike
    ], [
        void
    ], 'nonpayable'>;
    splCache: TypedContractMethod<[
        tokenId: BigNumberish
    ], [
        NFTBridgeStorage.SPLCacheStructOutput
    ], 'view'>;
    submitRecoverChainId: TypedContractMethod<[
        encodedVM: BytesLike
    ], [
        void
    ], 'nonpayable'>;
    tokenImplementation: TypedContractMethod<[], [string], 'view'>;
    transferNFT: TypedContractMethod<[
        token: AddressLike,
        tokenID: BigNumberish,
        recipientChain: BigNumberish,
        recipient: BytesLike,
        nonce: BigNumberish
    ], [
        bigint
    ], 'payable'>;
    upgrade: TypedContractMethod<[encodedVM: BytesLike], [void], 'nonpayable'>;
    wormhole: TypedContractMethod<[], [string], 'view'>;
    wrappedAsset: TypedContractMethod<[
        tokenChainId: BigNumberish,
        tokenAddress: BytesLike
    ], [
        string
    ], 'view'>;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: 'bridgeContracts'): TypedContractMethod<[chainId_: BigNumberish], [string], 'view'>;
    getFunction(nameOrSignature: 'chainId'): TypedContractMethod<[], [bigint], 'view'>;
    getFunction(nameOrSignature: 'completeTransfer'): TypedContractMethod<[encodedVm: BytesLike], [void], 'nonpayable'>;
    getFunction(nameOrSignature: 'encodeTransfer'): TypedContractMethod<[
        transfer: NFTBridgeStructs.TransferStruct
    ], [
        string
    ], 'view'>;
    getFunction(nameOrSignature: 'evmChainId'): TypedContractMethod<[], [bigint], 'view'>;
    getFunction(nameOrSignature: 'finality'): TypedContractMethod<[], [bigint], 'view'>;
    getFunction(nameOrSignature: 'governanceActionIsConsumed'): TypedContractMethod<[hash: BytesLike], [boolean], 'view'>;
    getFunction(nameOrSignature: 'governanceChainId'): TypedContractMethod<[], [bigint], 'view'>;
    getFunction(nameOrSignature: 'governanceContract'): TypedContractMethod<[], [string], 'view'>;
    getFunction(nameOrSignature: 'isFork'): TypedContractMethod<[], [boolean], 'view'>;
    getFunction(nameOrSignature: 'isInitialized'): TypedContractMethod<[impl: AddressLike], [boolean], 'view'>;
    getFunction(nameOrSignature: 'isTransferCompleted'): TypedContractMethod<[hash: BytesLike], [boolean], 'view'>;
    getFunction(nameOrSignature: 'isWrappedAsset'): TypedContractMethod<[token: AddressLike], [boolean], 'view'>;
    getFunction(nameOrSignature: 'onERC721Received'): TypedContractMethod<[
        operator: AddressLike,
        arg1: AddressLike,
        arg2: BigNumberish,
        arg3: BytesLike
    ], [
        string
    ], 'view'>;
    getFunction(nameOrSignature: 'parseRecoverChainId'): TypedContractMethod<[
        encodedRecoverChainId: BytesLike
    ], [
        NFTBridgeStructs.RecoverChainIdStructOutput
    ], 'view'>;
    getFunction(nameOrSignature: 'parseRegisterChain'): TypedContractMethod<[
        encoded: BytesLike
    ], [
        NFTBridgeStructs.RegisterChainStructOutput
    ], 'view'>;
    getFunction(nameOrSignature: 'parseTransfer'): TypedContractMethod<[
        encoded: BytesLike
    ], [
        NFTBridgeStructs.TransferStructOutput
    ], 'view'>;
    getFunction(nameOrSignature: 'parseUpgrade'): TypedContractMethod<[
        encoded: BytesLike
    ], [
        NFTBridgeStructs.UpgradeContractStructOutput
    ], 'view'>;
    getFunction(nameOrSignature: 'registerChain'): TypedContractMethod<[encodedVM: BytesLike], [void], 'nonpayable'>;
    getFunction(nameOrSignature: 'splCache'): TypedContractMethod<[
        tokenId: BigNumberish
    ], [
        NFTBridgeStorage.SPLCacheStructOutput
    ], 'view'>;
    getFunction(nameOrSignature: 'submitRecoverChainId'): TypedContractMethod<[encodedVM: BytesLike], [void], 'nonpayable'>;
    getFunction(nameOrSignature: 'tokenImplementation'): TypedContractMethod<[], [string], 'view'>;
    getFunction(nameOrSignature: 'transferNFT'): TypedContractMethod<[
        token: AddressLike,
        tokenID: BigNumberish,
        recipientChain: BigNumberish,
        recipient: BytesLike,
        nonce: BigNumberish
    ], [
        bigint
    ], 'payable'>;
    getFunction(nameOrSignature: 'upgrade'): TypedContractMethod<[encodedVM: BytesLike], [void], 'nonpayable'>;
    getFunction(nameOrSignature: 'wormhole'): TypedContractMethod<[], [string], 'view'>;
    getFunction(nameOrSignature: 'wrappedAsset'): TypedContractMethod<[
        tokenChainId: BigNumberish,
        tokenAddress: BytesLike
    ], [
        string
    ], 'view'>;
    getEvent(key: 'AdminChanged'): TypedContractEvent<AdminChangedEvent.InputTuple, AdminChangedEvent.OutputTuple, AdminChangedEvent.OutputObject>;
    getEvent(key: 'BeaconUpgraded'): TypedContractEvent<BeaconUpgradedEvent.InputTuple, BeaconUpgradedEvent.OutputTuple, BeaconUpgradedEvent.OutputObject>;
    getEvent(key: 'ContractUpgraded'): TypedContractEvent<ContractUpgradedEvent.InputTuple, ContractUpgradedEvent.OutputTuple, ContractUpgradedEvent.OutputObject>;
    getEvent(key: 'Upgraded'): TypedContractEvent<UpgradedEvent.InputTuple, UpgradedEvent.OutputTuple, UpgradedEvent.OutputObject>;
    filters: {
        'AdminChanged(address,address)': TypedContractEvent<AdminChangedEvent.InputTuple, AdminChangedEvent.OutputTuple, AdminChangedEvent.OutputObject>;
        AdminChanged: TypedContractEvent<AdminChangedEvent.InputTuple, AdminChangedEvent.OutputTuple, AdminChangedEvent.OutputObject>;
        'BeaconUpgraded(address)': TypedContractEvent<BeaconUpgradedEvent.InputTuple, BeaconUpgradedEvent.OutputTuple, BeaconUpgradedEvent.OutputObject>;
        BeaconUpgraded: TypedContractEvent<BeaconUpgradedEvent.InputTuple, BeaconUpgradedEvent.OutputTuple, BeaconUpgradedEvent.OutputObject>;
        'ContractUpgraded(address,address)': TypedContractEvent<ContractUpgradedEvent.InputTuple, ContractUpgradedEvent.OutputTuple, ContractUpgradedEvent.OutputObject>;
        ContractUpgraded: TypedContractEvent<ContractUpgradedEvent.InputTuple, ContractUpgradedEvent.OutputTuple, ContractUpgradedEvent.OutputObject>;
        'Upgraded(address)': TypedContractEvent<UpgradedEvent.InputTuple, UpgradedEvent.OutputTuple, UpgradedEvent.OutputObject>;
        Upgraded: TypedContractEvent<UpgradedEvent.InputTuple, UpgradedEvent.OutputTuple, UpgradedEvent.OutputObject>;
    };
}
//# sourceMappingURL=NFTBridge.d.ts.map