"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EvmAutomaticCircleBridge = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const constants_1 = require("../constants");
const types_1 = require("../types");
const unsignedTransaction_1 = require("../unsignedTransaction");
const contracts_1 = require("../contracts");
const platform_1 = require("../platform");
class EvmAutomaticCircleBridge {
    network;
    chain;
    provider;
    contracts;
    circleRelayer;
    chainId;
    // https://github.com/wormhole-foundation/wormhole-connect/blob/development/sdk/src/contexts/eth/context.ts#L379
    constructor(network, chain, provider, contracts) {
        this.network = network;
        this.chain = chain;
        this.provider = provider;
        this.contracts = contracts;
        if (network === 'Devnet')
            throw new Error('AutomaticCircleBridge not supported on Devnet');
        this.chainId = (0, constants_1.evmNetworkChainToEvmChainId)(network, chain);
        this.circleRelayer = this.contracts.getWormholeCircleRelayer(chain, provider);
    }
    static async fromProvider(provider, contracts) {
        const [network, chain] = await platform_1.EvmPlatform.chainFromRpc(provider);
        return new EvmAutomaticCircleBridge(network, chain, provider, contracts);
    }
    async *transfer(token, sender, recipient, amount, nativeGas) {
        const senderAddr = (0, types_1.toEvmAddrString)(sender);
        const recipientChainId = (0, connect_sdk_1.chainToChainId)(recipient.chain);
        const recipientAddress = recipient.address
            .toUniversalAddress()
            .toUint8Array();
        const nativeTokenGas = nativeGas ? nativeGas : 0n;
        const tokenAddr = (0, types_1.toEvmAddrString)(token.address.toUniversalAddress());
        const tokenContract = contracts_1.EvmContracts.getTokenImplementation(this.provider, tokenAddr);
        const allowance = await tokenContract.allowance(senderAddr, this.circleRelayer.target);
        if (allowance < amount) {
            const txReq = await tokenContract.approve.populateTransaction(this.circleRelayer.target, amount);
            yield this.createUnsignedTx((0, types_1.addFrom)(txReq, senderAddr), 'ERC20.approve of CircleRelayer');
        }
        const txReq = await this.circleRelayer.transferTokensWithRelay.populateTransaction(tokenAddr, amount, nativeTokenGas, recipientChainId, recipientAddress);
        yield this.createUnsignedTx((0, types_1.addFrom)(txReq, senderAddr), 'CircleRelayer.transfer');
    }
    createUnsignedTx(txReq, description, parallelizable = false) {
        return new unsignedTransaction_1.EvmUnsignedTransaction((0, types_1.addChainId)(txReq, this.chainId), this.network, this.chain, description, parallelizable);
    }
}
exports.EvmAutomaticCircleBridge = EvmAutomaticCircleBridge;
//# sourceMappingURL=automaticCircleBridge.js.map