import { Network, VAA, ChainAddress, TokenBridge, TxHash, TokenId, NativeAddress, TokenTransferTransaction } from '@wormhole-foundation/connect-sdk';
import { Provider } from 'ethers';
import { TokenBridgeContract } from '../ethers-contracts';
import { EvmUnsignedTransaction } from '../unsignedTransaction';
import { EvmContracts } from '../contracts';
import { EvmChainName, UniversalOrEvm } from '../types';
export declare class EvmTokenBridge implements TokenBridge<'Evm'> {
    readonly network: Network;
    readonly chain: EvmChainName;
    readonly provider: Provider;
    readonly contracts: EvmContracts;
    readonly tokenBridge: TokenBridgeContract;
    readonly chainId: bigint;
    private constructor();
    static fromProvider(provider: Provider, contracts: EvmContracts): Promise<EvmTokenBridge>;
    isWrappedAsset(token: UniversalOrEvm): Promise<boolean>;
    getOriginalAsset(token: UniversalOrEvm): Promise<TokenId>;
    hasWrappedAsset(token: TokenId): Promise<boolean>;
    getWrappedAsset(token: TokenId): Promise<NativeAddress<'Evm'>>;
    isTransferCompleted(vaa: VAA<'Transfer'> | VAA<'TransferWithPayload'>): Promise<boolean>;
    createAttestation(token: UniversalOrEvm): AsyncGenerator<EvmUnsignedTransaction>;
    submitAttestation(vaa: VAA<'AttestMeta'>): AsyncGenerator<EvmUnsignedTransaction>;
    transfer(sender: UniversalOrEvm, recipient: ChainAddress, token: UniversalOrEvm | 'native', amount: bigint, payload?: Uint8Array): AsyncGenerator<EvmUnsignedTransaction>;
    redeem(sender: UniversalOrEvm, vaa: VAA<'Transfer'> | VAA<'TransferWithPayload'>, unwrapNative?: boolean): AsyncGenerator<EvmUnsignedTransaction>;
    parseTransactionDetails(txid: TxHash): Promise<TokenTransferTransaction[]>;
    getWrappedNative(): Promise<NativeAddress<'Evm'>>;
    private createUnsignedTx;
}
//# sourceMappingURL=tokenBridge.d.ts.map